function a = InfluenceAtDepth(D, s, q)
    % this function returns the influence of the point s on the point q at
    % scale  2^-D, i.e. depth D.
    % a = \sum_(o in Neighb(D, s)) a_(o,s) F_o (q).
    if norm( s - q, Inf) * 2^D >= 3   % i.e. q is out of a square 
        a = 0;
    else
        s_sc = s * 2^D + 0.5;
        foo = s_sc - floor(s_sc);
        x = foo(1); y = foo(2);
        o1 = floor(s_sc) / 2^D;
        o4 = o1 + 1/2^D;
        o2 = [o1(1), o4(2)];
        o3 = [o4(1), o1(2)];
        
        o1 = o1 - 0.5/2^D;
        o2 = o2 - 0.5/2^D;
        o3 = o3 - 0.5/2^D;
        o4 = o4 - 0.5/2^D;
        
        a = (1-x)*(1-y)*F_aux(o1, q) ...
            + x*(1-y)*F_aux(o2,q) ...
            + (1-x)*y*F_aux(o3,q) ...
            + x * y * F_aux(o4,q);
        
    end;    
    function r = F_aux(o, t)
        r = F( (t(1)-o(1))*(2^D), (t(2)-o(2))*(2^D)) * 4^D;
    end
end